@@ -1,10 +1,10 @@
 
 
-VERSION = (0, 5, 0)
+VERSION = (1, 0, 0)
 """Application version number tuple."""
 
 VERSION_STR = '.'.join(map(str, VERSION))
 """Application version number string."""
 
 
-default_app_config = 'siteajax.config.SiteajaxConfig'
\ No newline at end of file
+default_app_config = 'siteajax.apps.SiteajaxConfig'
\ No newline at end of file
